/*
 * Copyright (c) OSGi Alliance (2013, 2016). All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * OSGi Versioning Annotations Package Version 1.1.
 * <p>
 * This package is not used at runtime.
 *
 * @see <a href=
 *      "https://www.osgi.org/wp-content/uploads/SemanticVersioning1.pdf" >
 *      Semantic Versioning</a>
 * @author $Id: 2ff0bf766254e2570f961cd0260349635fa5ed3b $
 */
@Version("1.1")
package org.osgi.annotation.versioning;

